@@ -49,7 +49,7 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
                           params='--flavor m1.tiny')
 
     def test_admin_flavor_list(self):
-        self.assertIn("Memory_MB", self.nova('flavor-list'))
+        self.assertIn("Memory_MiB", self.nova('flavor-list'))
 
     def test_admin_hypervisor_list(self):
         self.nova('hypervisor-list')
@@ -86,7 +86,11 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
         self.nova('help')
 
     def test_admin_list_extensions(self):
-        self.nova('list-extensions')
+        output = self.nova('list-extensions', merge_stderr=True)
+        self.assertIn(
+            'The API extension interface has been deprecated. This command '
+            'will be removed in the first major release after '
+            'the Nova server 20.0.0 Train release.', output)
 
     def test_agent_list(self):
         self.nova('agent-list')
@@ -124,4 +128,4 @@ class SimpleReadOnlyNovaClientTest(base.ClientTestBase):
         self.assertRaises(exceptions.CommandFailed,
                           self.nova,
                           'list',
-                          flags='--endpoint-override badurl')
+                          flags='--os-endpoint-override badurl')
