@@ -291,6 +291,7 @@ class Server(base.Resource):
         """
         return self.manager.shelve_offload(self)
 
+    @api_versions.wraps("2.0", "2.76")
     def unshelve(self):
         """
         Unshelve -- Unshelve the server.
@@ -299,10 +300,27 @@ class Server(base.Resource):
         """
         return self.manager.unshelve(self)
 
+    @api_versions.wraps("2.77")
+    def unshelve(self, availability_zone=None):
+        """
+        Unshelve -- Unshelve the server.
+
+        :param availability_zone: The specified availability zone name
+                                  (Optional)
+        :returns: An instance of novaclient.base.TupleWithMeta
+        """
+        return self.manager.unshelve(self,
+                                     availability_zone=availability_zone)
+
     def diagnostics(self):
         """Diagnostics -- Retrieve server diagnostics."""
         return self.manager.diagnostics(self)
 
+    @api_versions.wraps("2.78")
+    def topology(self):
+        """Retrieve server topology."""
+        return self.manager.topology(self)
+
     @api_versions.wraps("2.0", "2.55")
     def migrate(self):
         """
@@ -694,7 +712,8 @@ class ServerManager(base.BootingManagerWithFind):
               block_device_mapping_v2=None, nics=None, scheduler_hints=None,
               config_drive=None, admin_pass=None, disk_config=None,
               access_ip_v4=None, access_ip_v6=None, description=None,
-              tags=None, trusted_image_certificates=None, **kwargs):
+              tags=None, trusted_image_certificates=None,
+              host=None, hypervisor_hostname=None, **kwargs):
         """
         Create (boot) a new server.
         """
@@ -817,6 +836,12 @@ class ServerManager(base.BootingManagerWithFind):
             body['server']['trusted_image_certificates'] = (
                 trusted_image_certificates)
 
+        if host:
+            body['server']['host'] = host
+
+        if hypervisor_hostname:
+            body['server']['hypervisor_hostname'] = hypervisor_hostname
+
         return self._create('/servers', body, response_key,
                             return_raw=return_raw, **kwargs)
 
@@ -839,7 +864,7 @@ class ServerManager(base.BootingManagerWithFind):
             match the search_opts (optional). The search opts format is a
             dictionary of key / value pairs that will be appended to the query
             string.  For a complete list of keys see:
-            https://developer.openstack.org/api-ref/compute/#list-servers
+            https://docs.openstack.org/api-ref/compute/#list-servers
         :param marker: Begin returning servers that appear later in the server
                        list than that represented by this server id (optional).
         :param limit: Maximum number of servers to return (optional).
@@ -1215,6 +1240,7 @@ class ServerManager(base.BootingManagerWithFind):
         """
         return self._action('shelveOffload', server, None)
 
+    @api_versions.wraps("2.0", "2.76")
     def unshelve(self, server):
         """
         Unshelve the server.
@@ -1224,6 +1250,21 @@ class ServerManager(base.BootingManagerWithFind):
         """
         return self._action('unshelve', server, None)
 
+    @api_versions.wraps("2.77")
+    def unshelve(self, server, availability_zone=None):
+        """
+        Unshelve the server.
+
+        :param server: The :class:`Server` (or its ID) to unshelve
+        :param availability_zone: The specified availability zone name
+                                  (Optional)
+        :returns: An instance of novaclient.base.TupleWithMeta
+        """
+        info = None
+        if availability_zone:
+            info = {'availability_zone': availability_zone}
+        return self._action('unshelve', server, info)
+
     def ips(self, server):
         """
         Return IP Addresses associated with the server.
@@ -1250,6 +1291,19 @@ class ServerManager(base.BootingManagerWithFind):
                                          base.getid(server))
         return base.TupleWithMeta((resp, body), resp)
 
+    @api_versions.wraps("2.78")
+    def topology(self, server):
+        """
+        Retrieve server topology.
+
+        :param server: The :class:`Server` (or its ID) for which
+                       topology to be returned
+        :returns: An instance of novaclient.base.DictWithMeta
+        """
+        resp, body = self.api.client.get("/servers/%s/topology" %
+                                         base.getid(server))
+        return base.DictWithMeta(body, resp)
+
     def _validate_create_nics(self, nics):
         # nics are required with microversion 2.37+ and can be a string or list
         if self.api_version > api_versions.APIVersion('2.36'):
@@ -1267,7 +1321,9 @@ class ServerManager(base.BootingManagerWithFind):
                nics=None, scheduler_hints=None,
                config_drive=None, disk_config=None, admin_pass=None,
                access_ip_v4=None, access_ip_v6=None,
-               trusted_image_certificates=None, **kwargs):
+               trusted_image_certificates=None,
+               host=None, hypervisor_hostname=None,
+               **kwargs):
         # TODO(anthony): indicate in doc string if param is an extension
         # and/or optional
         """
@@ -1334,6 +1390,10 @@ class ServerManager(base.BootingManagerWithFind):
                      server as tags (allowed since microversion 2.52)
         :param trusted_image_certificates: A list of trusted certificate IDs
                                            (allowed since microversion 2.63)
+        :param host: requested host to create servers
+                     (allowed since microversion 2.74)
+        :param hypervisor_hostname: requested hypervisor hostname to create
+                                    servers (allowed since microversion 2.74)
         """
         if not min_count:
             min_count = 1
@@ -1388,6 +1448,15 @@ class ServerManager(base.BootingManagerWithFind):
                         "Block device volume_type is not supported before "
                         "microversion 2.67")
 
+        host_microversion = api_versions.APIVersion("2.74")
+        if host and self.api_version < host_microversion:
+            raise exceptions.UnsupportedAttribute("host", "2.74")
+        hypervisor_hostname_microversion = api_versions.APIVersion("2.74")
+        if (hypervisor_hostname and
+                self.api_version < hypervisor_hostname_microversion):
+            raise exceptions.UnsupportedAttribute(
+                "hypervisor_hostname", "2.74")
+
         boot_kwargs = dict(
             meta=meta, files=files, userdata=userdata,
             reservation_id=reservation_id, min_count=min_count,
@@ -1396,7 +1465,9 @@ class ServerManager(base.BootingManagerWithFind):
             scheduler_hints=scheduler_hints, config_drive=config_drive,
             disk_config=disk_config, admin_pass=admin_pass,
             access_ip_v4=access_ip_v4, access_ip_v6=access_ip_v6,
-            trusted_image_certificates=trusted_image_certificates, **kwargs)
+            trusted_image_certificates=trusted_image_certificates,
+            host=host, hypervisor_hostname=hypervisor_hostname,
+            **kwargs)
 
         if block_device_mapping:
             boot_kwargs['block_device_mapping'] = block_device_mapping
